@@ -1,8 +1,8 @@
 package Email::Sender::Transport::SMTP;
-our $VERSION = '0.091740';
+our $VERSION = '0.091870';
 
 use Moose;
-with 'Email::Sender::Transport';
+with 'Email::Sender::Transport' => { excludes => 'allow_partial_success' };
 # ABSTRACT: send email over SMTP
 
 use Email::Sender::Failure::Multi;
@@ -168,7 +168,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 0.091740
+version 0.091870
 
 =head1 DESCRIPTION
 
